@@ -67,17 +67,13 @@ $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularrat
 toil genstar solvestar integratebox filterbox__ cleanitem
 );
 
-$VERSION = '0.153';
+$VERSION = '0.155';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
 # Sim::OPT
 #################################################################################
 
-# FUNCTIONS' SPACE
-###########################################################
-###########################################################
-
 
 sub checkdone
 {
@@ -529,6 +525,7 @@ sub getrootname
 }
 
 
+
 sub extractcase #  UPDATES THE FILE NAME ON THE BASIS OF A %carrier
 {
 	my ( $transfile, $carrier_r, $file, $blockelts_r ) = @_;
@@ -536,17 +533,18 @@ sub extractcase #  UPDATES THE FILE NAME ON THE BASIS OF A %carrier
 	#say $tee "In extractcase; \$carrier_r: " . dump( $carrier_r) ;
 	#say $tee "In extractcase; \$file: " . dump( $file) ;
 	my %carrier = %{ $carrier_r };
-	my $num = keys( %carrier ); #say $tee "In extractcase; \$num: " . dump( $num) ;
 	my @blockelts = @{ $blockelts_r };
+	my $num = scalar( @blockelts ); #ay $tee "In extractcase; \$num: " . dump( $num) ;
 
 	my $counter = 0;
 	my %provhash;
-	while ($counter < $num)
+	while ( $counter < $num )
 	{
 		$transfile =~ s/^$file//; #say $tee "In extractcase1; \$transfile: " . dump( $transfile) ;
 		$transfile =~ s/^_//; #say $tee "In extractcase2; \$transfile: " . dump( $transfile) ;
 
 		$transfile =~ /^(\d+)-(\d+)/;
+
 		if ( ($1) and ($2) )
 		{
 			$provhash{$1} = $2; #say $tee "In extractcase3; \$transfile: " . dump( $transfile) ;
@@ -572,9 +570,9 @@ sub extractcase #  UPDATES THE FILE NAME ON THE BASIS OF A %carrier
 			$carrier{$key} = $provhash{$key};
 		}
 	}
-	#say $tee "In extractcase; \%carrier: " . dump( \%carrier ) ;
+	#say $tee "In extractcase, OBTAINED \%carrier: " . dump( \%carrier ) ;
 	my $to = makefilename( %carrier ); #say $tee "In extractcase, RESULT1:; \$to: " . dump( $to) ;
-	$to = Sim::OPT::cleanitem( $to, $mypath, $file ); #say $tee "In extractcase, RESULT2:; \$to: " . dump( $to) ;
+	$to = Sim::OPT::cleanitem( $to, $mypath, $file ); #say $tee "In extractcase, NAME:; \$to: " . dump( $to) ;
 	return( $to );
 }
 
@@ -788,9 +786,9 @@ sub integratebox
 		my @elts = @{ $eltref };
 		my $target = $elts[0]; #say $tee "IN INTEGRATEBOX Target $target" ;
 		my $righttarget = extractcase( $target, \%carrier, $file, \@blockelts ); #say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
-		my $lasttarget = $elts[3]; #say $tee "IN INTEGRATEBOX lasttarget $lasttarget" ;
-		my $pasttarget = extractcase( $lasttarget, \%carrier, $file, @blockelts ); #say $tee "IN INTEGRATEBOX pasttarget $pasttarget" ;; #say $tee "IN INTEGRATEBOX Target $target" ;
-		push (@newbox, [ $righttarget, $elts[1], $elts[2], $pasttarget, $elts[2] ] );
+		my $origin = $elts[3]; #say $tee "IN INTEGRATEBOX \$origin $origin" ;
+		my $rightorigin = extractcase( $origin, \%carrier, $file, \@blockelts ); #say $tee "IN INTEGRATEBOX \$rightorigin $rightorigin";
+		push (@newbox, [ $righttarget, $elts[1], $elts[2], $rightorigin, $elts[4] ] );
 	} #say $tee "IN INTEGRATEBOX \@newbox " . dump( @newbox ) ;
 	return ( \@newbox );
 }
@@ -1333,9 +1331,9 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	my @blocks = @{ $d{blocks} }; #say $tee "IN DEFFILES \@blocks : " . dump( @blocks );
 	my $toitem = $d{toitem}; #say $tee "IN12 DEFFILES12 \$toitem : " . dump( $toitem );
 	my $from = $d{from}; #say $tee "IN DEFFILES \$from " . dump( $from );
-	my %varnums = %{ $d{varnums} }; #say $tee "IN DEFFILES \%varnums " . dump( \%varnums );
-	my %mids = %{ $d{mids} }; #say $tee "IN DEFFILES \%mids " . dump( \%mids );
-	my %carrier = %{ $d{carrier} }; #say $tee "IN DEFFILES \%carrier " . dump( \%carrier );
+	my %varnums = %{ $d{varnums} }; say $tee "IN DEFFILES \%varnums " . dump( \%varnums );
+	my %mids = %{ $d{mids} }; say $tee "IN DEFFILES \%mids " . dump( \%mids );
+	my %carrier = %{ $d{carrier} }; say $tee "IN DEFFILES \%carrier " . dump( \%carrier );
 
 	say $tee "IN IN DEFFILES  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 	my $file = $dowhat{file}; #say $tee "IN DEFFILES \$file " . dump( $file );
@@ -1406,22 +1404,22 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		{
 			my @dummys = ( $elt );
 			my @bix = @{ toil( \@dummys, \%varnums, \@basket, $c ) };
-			@bix = @{ $bix[0] };
-			push( @bux, @bix );
+			#@bix = @{ $bix[0] };
+			my @bark = @{ flattenbox( @bix ) };
+			push( @bux, @bark );
 			$c++;
 		}
 	}
 	else
 	{
-		#say $tee "DOING BOX \$dirfiles{starsign} : " . dump( $dirfiles{starsign} );
+		say $tee "IN DEFFFILES RIGHT \$dirfiles{starsign} : " . dump( $dirfiles{starsign} );
 		@bux = @{ toil( \@blockelts, \%varnums, \@basket ) };
-		@bux = uniq( @{ $bux[-1] } );
 	} say $tee "IN DEFFILES2 \@bux: " . dump( @bux );
 	#say $tee "IN DEFFILES2 \$countblock : " . dump( $countblock );
 	#say $tee "IN DEFFILES \@blockelts : " . dump( @blockelts );
 
 	#############my $flattened_r = flattenbox( \@bux ); 	say $tee "IN DEFFILES2 \$flattened_r: " . dump( $flattened_r );
-
+	say $tee "In DEFFILES5 \%mids!: " . dump ( %mids );
 	my ( @finalbox );
 	if ( $dirfiles{starsign} eq "yes" )
 	{
@@ -1436,10 +1434,12 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	}
 	else
 	{
-		@finalbox = uniq( @{ integratebox( \@bux, \%carrier, $file, \@blockelts ) } );
+		say $tee "IN DEFFILES RIGHT AFTER " ;
+		my @bark = @{ flattenbox( \@bux ) };
+		@finalbox = uniq( @{ integratebox( \@bark, \%carrier, $file, \@blockelts ) } );
 	}
 
-	@finalbox = sort { $a->[0] <=> $b->[0] } @finalbox; #say $tee "In DEFFILES5 \@finalbox!: " . dump ( @finalbox );
+	@finalbox = sort { $a->[0] <=> $b->[0] } @finalbox; say $tee "In DEFFILES5 \@finalbox!: " . dump ( @finalbox );
 
 
 	setlaunch( {
@@ -1478,7 +1478,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 	my %varnums = %{ $d{varnums} }; #say $tee "IN SETLAUNCH \%varnums " . dump( %varnums );
 	my %mids = %{ $d{mids} }; #say $tee "IN SETLAUNCH \%mids" . dump( \%mids ); ### DDD
 	my %carrier = %{ $d{carrier} }; #say $tee "IN SETLAUNCH \%carrier" . dump( \%carrier ); ### DDD
-	say $tee "IN IN SETLAUNCH  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	#say $tee "IN IN SETLAUNCH  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 
 	my ( @instances );
 
@@ -1490,8 +1490,8 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 		my $countvar = $$elt[1];
 		my $countstep = $$elt[2];
 		my $oldpars = $$elt[3];
-		my $to = extractcase( $newpars, \%carrier );
-		my $origin = extractcase( $oldpars, \%carrier );
+		my $to = extractcase( $newpars, \%carrier, $file, \@blockelts );
+		my $origin = extractcase( $oldpars, \%carrier, $file, \@blockelts );
 		my $c = $$elt[4];
 
 		push ( @instances,
@@ -1504,7 +1504,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 			sourcesweeps => \@sourcesweeps, datastruc => \%datastruc,
 			varnumbers => \@varnumbers, blocks => \@blocks,
 			blockelts => \@blockelts, mids => \%mids, varnums => \%varnums,
-			countinstance => $count, carrier => \%carrier,
+			countinstance => $count, carrier => \%carrier, origin => $origin
 		} );
 		$count++;
 
@@ -1515,7 +1515,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 sub exe
 {
 	my %dat = %{ $_[0] };
-	my @instances = @{ $dat{instances} }; #say $tee "IN EXE \@instances " . dump( @instances );
+	my @instances = @{ $dat{instances} }; say $tee "IN EXE \@instances " . dump( @instances );
 	my %dirfiles = %{ $dat{dirfiles} }; #say $tee "IN EXE \%dirfiles " . dump( %dfromirfiles );
 
 	my %d = %{ $instances[0] }; #say $tee "IN EXE \%d!!! " . dump( \%d );
@@ -1536,22 +1536,6 @@ sub exe
 	my $countstep = $d{countstep}; say $tee "IN12 EXE \$countstep : " . dump( $countstep );
 	say $tee "IN EXE  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 
-	#my ( $direction, $starorder );
-	#if ( $dowhat{outstarmode} eq "yes" )
-	#{
-	#	$direction = ${$dowhat{direction}}[$countcase][$countblock]; #say $tee "IN EXE \$direction " . dump( $direction ); #NEW
-	#	$starorder = ${$dowhat{starorder}}[$countcase][$countblock]; #say $tee "IN EXE \$starorder " . dump( $starorder ); #NEW
-	#}
-	#else
-	#{
-	#	$direction = $dirfiles{direction}; #say $tee "IN EXE \$direction " . dump( $direction ); #NEW
-	#	$starorder = $dirfiles{starorder}; #say $tee "IN EXE \$starorder " . dump( $starorder ); #NEW
-	#	if ( $direction eq "" ){ $direction = ${$dowhat{direction}}[$countcase][$countblock]; }
-	#	if ( $starorder eq "" ){ $starorder = ${$docarrierwhat{starorder}}[$countcase][$countblock]; }
-	#}
-	#say $tee "IN EXE \$direction " . dump( $direction ); #NEW
-	#say $tee "IN EXE \$starorder " . dump( $starorder ); #NEW
-
 	my $precomputed = $dowhat{precomputed}; say $tee "IN EXE \$precomputed " . dump( $precomputed ); #NEW
   my @takecolumns = @{ $dowhat{takecolumns} }; say $tee "IN EXE \@takecolumns " . dump( @takecolumns ); #NEW
 	my ( @simcases, @simstruct );
@@ -1561,7 +1545,7 @@ sub exe
 	{
 		say $tee "#Calling morphing operations for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 
-		my @result = Sim::OPT::Morph::morph( { configfile => $configfile, instances => \@instances, dirfiles => \%dirfiles } );
+		my @result = Sim::OPT::Morph::morph( $configfile, \@instances, \%dirfiles, \%dowhat );
 		$dirfiles{morphcases} = $result[0];
 		$dirfiles{morphstruct} = $result[1];
 	}
