@@ -38,7 +38,7 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.93'; # our $VERSION = '';
+$VERSION = '0.111'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -119,7 +119,7 @@ sub descend
 
   say $tee "IN ENTRY DESCEND3  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 
-  my %d = %{ $instances[0] }; say $tee "IN ENTRY DESCEND3 \%d : " . dump( \%d );
+  my %d = %{ $instances[0] }; #say $tee "IN ENTRY DESCEND3 \%d : " . dump( \%d );
   my $countcase = $d{countcase}; say $tee "IN ENTRY DESCEND \$countcase : " . dump( $countcase );
   my $countblock = $d{countblock}; say $tee "IN ENTRY DESCEND \$countblock : " . dump( $countblock );
   my %datastruc = %{ $d{datastruc} }; ######
@@ -228,7 +228,7 @@ sub descend
   my $entryname = $dirfiles{entryname}; say $tee "IN DESCEND \$entryname: " . dump( $entryname );
   if ( $entryname ne "" )
   {
-    $entryfile = "$mypath/" . "$file" . "_" . "$entryname" . ".csv";
+    $entryfile = "$mypath/" . "$file" . "_tmp_" . "$entryname" . ".csv";
   }
   else
   {
@@ -238,7 +238,7 @@ sub descend
   my $exitname = $dirfiles{exitname}; say $tee "IN DESCEND \$exitname: " . dump( $exitname );
   if ( $exitname ne "" )
   {
-    $exitfile = "$mypath/" . "$file" . "_" . "$exitname" . ".csv";
+    $exitfile = "$mypath/" . "$file" . "_tmp_" . "$exitname" . ".csv";
   }
   else
   {
@@ -248,7 +248,7 @@ sub descend
   my $orderedname = "$exitname" . "-ord";
   if ( $orderedname ne "" )
   {
-    $orderedfile = "$mypath/" . "$file" . "_" . "$orderedname" . ".csv";
+    $orderedfile = "$mypath/" . "$file" . "_tmp_" . "$orderedname" . ".csv";
   }
   else
   {
@@ -798,12 +798,13 @@ sub descend
 
   sub metamodel
 	{
-    my ( $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile, $direction, $starorder, $ordmeta, $varnums_r ) = @_;
+    my ( $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile, $direction, $starorder, $ordmeta, $varnums_r, $countblock ) = @_;
     my %dowhat = %{ $dowhat_r };
     my %dirfiles = %{ $dirfiles_r };
     my @blockelts = @{ $blockelts_r }; #say $tee " IN metamodel \@blockelts : " . dump( @blockelts );
     my %carrier = %{ $carrier_r };
     my %varnums = %{ $varnums_r };
+    say $tee " IN metamodel \$countblock : " . dump( $countblock );
     close SORTMIXED;
 
 	  #my ( $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $mids_r, $metafile, $direction, $starorder, $ordmeta ) = @_;
@@ -814,7 +815,7 @@ sub descend
 		  {
 		    my ( $sortmixed ) = @_;
 		    open( ORDRES, "$sortmixed") or die;
-		    my $cleanordres = $sortmixed . "_cleaned.csv";
+		    my $cleanordres = $sortmixed . "_tmp_cleaned.csv";
 		    my @lines = <ORDRES>;
 	      close ORDRES;
 
@@ -959,7 +960,7 @@ sub descend
       #say $tee "TO PREPAREBLANK \%carrier : " . dump( \%carrier); say $tee "\@blockelts : " . dump( @blockelts );
 
       my $cleanordres = cleanres( $sortmixed ); #say $tee "IN TAKEOPTIMA1 \$cleanordres : " . dump( $cleanordres );
-	    my $blankfile = "$sortmixed" . "_blank.csv";
+	    my $blankfile = "$sortmixed" . "_tmp_blank.csv";
 	    my $bit = $file . "_";
 	    my @bag =( $bit );
 	    prepareblank( \%varns, $blankfile, \@blockelts, \@bag, $file, \%carrier ) ;
@@ -1026,8 +1027,8 @@ sub descend
         return( %torecovers );
       }
 
-      my $prepblank = $sortmixed . "_prepblank.csv";
-      my $prepsort = $sortmixed . "_prepsort.csv";
+      my $prepblank = $sortmixed . "_tmp_prepblank.csv";
+      my $prepsort = $sortmixed . "_tmp_prepsort.csv";
       #say $tee "BEFORE PREPFILE \%carrier " . dump( \%carrier );
       #say $tee "BEFORE PREPFILE \%varnums " . dump( \%varnums );
       my %torecovers = prepfile( $blankfile, $prepblank, $cleanordres, $prepsort, \@blockelts, \%varnums, \%carrier, $metafile ); say $tee "FROM PREPFILE \%torecovers " . dump( \%torecovers );
@@ -1073,28 +1074,28 @@ sub descend
 	      close PREPFILE;
 	    }
 
-      my $prepfile = $sortmixed . "_prepfile.csv";
+      my $prepfile = $sortmixed . "_tmp_prepfile.csv";
 	    jointwo( $prepsort, $prepblank, $prepfile ) ;
 
-      my $rawmetafile = $metafile . "_raw.csv";
+      my $rawmetafile = $metafile . "_tmp_raw.csv";
 	    say $tee "ABOUT TO LAUNCH INTERLINEAR";
-	    say $tee "IN TAKEOPTIMA \$confinterlinear: " . dump($confinterlinear);
-      say $tee "IN TAKEOPTIMA \$prepfile: " . dump($prepfile);
-	    say $tee "IN TAKEOPTIMA \$metafile: " . dump($metafile);
-	    say $tee "IN TAKEOPTIMA \@blockelts: " . dump(@blockelts);
-	    Sim::OPT::Interlinear::interlinear( $confinterlinear, $prepfile, $rawmetafile, \@blockelts, $tofile );
+	    say $tee "WITH, IN TAKEOPTIMA \$confinterlinear: " . dump($confinterlinear);
+      say $tee "WITH, IN TAKEOPTIMA \$prepfile: " . dump($prepfile);
+	    say $tee "WITH, IN TAKEOPTIMA \$metafile: " . dump($metafile);
+	    say $tee "WITH, IN TAKEOPTIMA \@blockelts: " . dump(@blockelts);
+      say $tee "WITH, IN TAKEOPTIMA \$countblock: " . dump($countblock);
+	    Sim::OPT::Interlinear::interlinear( $confinterlinear, $prepfile, $rawmetafile, \@blockelts, $tofile, $countblock );
 
       open( RAWMETAFILE, "$rawmetafile" ) or die;
       my @rawlines = <RAWMETAFILE>;
       close RAWMETAFILE;
 
       open( METAFILE, ">$metafile" ) or die;
-      
       foreach my $line ( @rawlines )
-      {
+      { #say $tee "CHECK. \%torecovers " . dump( %torecovers );
         foreach my $key ( keys %torecovers )
         {
-          s/$key-\d+/$key-$torecovers{$key}/ ;
+          $line =~ s/$key-\d+/$key-$torecovers{$key}/ ;
         }
         print METAFILE $line;
       }
@@ -1401,7 +1402,8 @@ sub descend
 
         my @blockelts = @{ Sim::OPT::getblockelts( \@sweeps, $countcase, $countblock ) }; say $tee "IN callblock \@blockelts " . dump( @blockelts );
 
-        metamodel( \%dowhat, $sortmixed, $file, \%dirfiles, \@blockelts, \%carrier, $metafile, $direction, $starorder, $ordmeta, \%varnums );
+        say $tee "ABOUT TO CALL METAMODEL WITH COUNT EQUAL TO MAX; \$countblock: $countblock";
+        metamodel( \%dowhat, $sortmixed, $file, \%dirfiles, \@blockelts, \%carrier, $metafile, $direction, $starorder, $ordmeta, \%varnums, $countblock );
 
         my @lines;
         if ( $dirfiles{metamodel} eq "yes" )
@@ -1527,14 +1529,15 @@ sub descend
         #say $tee "HERE AGAIN?!";
         #say $tee "HERE \$#blockelts : " . dump( $#blockelts );
 
-        my $metafile = $sortmixed . "_meta.csv";
+        my $metafile = $sortmixed . "_tmp_meta.csv";
         my $ordmeta = $sortmixed . "_ordmeta.csv";
 
         #say $tee "CARRIER " . dump( %carrier );
 
         my @blockelts = @{ Sim::OPT::getblockelts( \@sweeps, $countcase, $countblock ) }; say $tee "IN callblock \@blockelts " . dump( @blockelts );
 
-        metamodel( \%dowhat, $sortmixed, $file, \%dirfiles, \@blockelts, \%carrier, $metafile, $direction, $starorder, $ordmeta, \%varnums );
+        say $tee "ABOUT TO CALL METAMODEL WITH COUNT LESSER THAN MAX; \$countblock: $countblock";
+        metamodel( \%dowhat, $sortmixed, $file, \%dirfiles, \@blockelts, \%carrier, $metafile, $direction, $starorder, $ordmeta, \%varnums, $countblock );
 
         my @lines;
         if ( $dirfiles{metamodel} eq "yes" )
